/*
Copyright (c) NAVER Corp.
name: @egjs/vue2-imready
license: MIT
author: NAVER Corp.
repository: https://github.com/naver/egjs-imready
version: 1.0.0
*/
'use strict';

var ImReady = require('@egjs/imready');
var compositionApi = require('@vue/composition-api');

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
var __assign = function () {
  __assign = Object.assign || function __assign(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];

      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }

    return t;
  };

  return __assign.apply(this, arguments);
};
function __rest(s, e) {
  var t = {};

  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];

  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
}
function __read(o, n) {
  var m = typeof Symbol === "function" && o[Symbol.iterator];
  if (!m) return o;
  var i = m.call(o),
      r,
      ar = [],
      e;

  try {
    while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
  } catch (error) {
    e = {
      error: error
    };
  } finally {
    try {
      if (r && !r.done && (m = i["return"])) m.call(i);
    } finally {
      if (e) throw e.error;
    }
  }

  return ar;
}
/** @deprecated */

function __spread() {
  for (var ar = [], i = 0; i < arguments.length; i++) ar = ar.concat(__read(arguments[i]));

  return ar;
}

/**
 * Vue hook to check if the images or videos are loaded.
 * @ko 이미지와 비디오들이 로드가 됐는지 체크하는 Vue hook.
 * @memberof Vue2ImReady
 * @param - Vue ImReady's props <ko> Vue ImReady의 props.</ko>
 * @example
 * ```js
 * import { useImReady } from "@egjs/vue2-imready";
 *
 * setup() {
 *   const im = useImReady({
 *         selector: "img",
 *     });
 *
 *   return {
 *      im,
 *      container: im.register(),
 *   }
 * }
 * // {{im.readyCount}}
 * // &lt;div v-bind:ref="container"&gt;&lt;/div&gt;
 * ```
 */

function useImReady(props) {
  if (props === void 0) {
    props = {};
  }

  var _a = props.usePreReady,
      usePreReady = _a === void 0 ? true : _a,
      _b = props.usePreReadyElement,
      usePreReadyElement = _b === void 0 ? true : _b,
      _c = props.useReady,
      useReady = _c === void 0 ? true : _c,
      _d = props.useReadyElement,
      useReadyElement = _d === void 0 ? true : _d,
      _e = props.useError,
      useError = _e === void 0 ? true : _e,
      _f = props.selector,
      selector = _f === void 0 ? "" : _f,
      options = __rest(props, ["usePreReady", "usePreReadyElement", "useReady", "useReadyElement", "useError", "selector"]);

  var refs = [];
  var state = compositionApi.reactive({
    preReadyCount: 0,
    readyCount: 0,
    errorCount: 0,
    totalErrorCount: 0,
    totalCount: 0,
    isPreReady: false,
    isReady: false,
    isPreReadyOver: false,
    hasError: false,
    register: function (refOption) {
      if (refOption === void 0) {
        refOption = compositionApi.ref();
      }

      refs.push(refOption);
      return refOption;
    }
  });
  var imRef = compositionApi.ref();
  compositionApi.onMounted(function () {
    var im = new ImReady(options);
    imRef.value = im;
    var checkedElements = refs.map(function (childRef) {
      return childRef.value;
    });

    if (selector) {
      checkedElements = checkedElements.reduce(function (prev, cur) {
        return __spread(prev, cur.querySelectorAll(selector));
      }, []);
    }

    im.check(checkedElements).on("error", function (e) {
      if (useError) {
        state.hasError = true;
        state.errorCount = e.errorCount;
        state.totalErrorCount = e.totalErrorCount;
      }
    }).on("preReadyElement", function (e) {
      if (usePreReadyElement) {
        state.preReadyCount = e.preReadyCount;
      }
    }).on("readyElement", function (e) {
      if (useReadyElement) {
        state.readyCount = e.readyCount;
        state.isPreReadyOver = e.isPreReadyOver;
      }
    }).on("preReady", function () {
      if (usePreReady) {
        state.isPreReady = true;
      }
    }).on("ready", function () {
      if (useReady) {
        state.isReady = true;
      }
    });
    console.log(im.getTotalCount());
    state.preReadyCount = 0;
    state.readyCount = 0;
    state.errorCount = 0;
    state.totalErrorCount = 0;
    state.totalCount = im.getTotalCount();
    state.isReady = false;
    state.isPreReady = false;
    state.hasError = false;
    state.isPreReadyOver = false;
  });
  compositionApi.onBeforeUnmount(function () {
    var _a;

    (_a = imRef.value) === null || _a === void 0 ? void 0 : _a.destroy();
  });
  return state;
}

/**
 * Vue hook to check if the images or videos are loaded. (only `usePreReadyElement`, `usePreReady` and `useError` are true)
 * @ko 이미지와 비디오들이 로드가 됐는지 체크하는 Vue hook.(`usePreReadyElement`, `usePreReady`와 `useError`만 true)
 * @memberof Vue2ImReady
 * @param - Vue ImReady's props <ko>Vue ImReady의 props.</ko>
 * @example
 * ```js
 * import { usePreReadyElement } from "@egjs/vue2-imready";
 *
 * setup() {
 *   const im = usePreReadyElement({
 *         selector: "img",
 *     });
 *
 *   return {
 *      im,
 *      container: im.register(),
 *   }
 * }
 * // {{im.preReadyCount}}
 * // &lt;div v-bind:ref="container"&gt;&lt;/div&gt;
 * ```
 */

function usePreReadyElement(props) {
  if (props === void 0) {
    props = {};
  }

  return useImReady(__assign({
    useReady: false,
    useReadyElement: false
  }, props));
}

/**
 * Vue hook to check if the images or videos are loaded. (only `useReadyElement`, `useReady` and `useError` are true)
 * @ko 이미지와 비디오들이 로드가 됐는지 체크하는 vue hook.(`useReadyElement`, `useReady`와 `useError`만 true)
 * @memberof Vue2ImReady
 * @param - Vue ImReady's props <ko>Vue ImReady의 props.</ko>
 * @example
 * ```js
 * import { useReadyElement } from "@egjs/vue2-imready";
 *
 * setup() {
 *   const im = useReadyElement({
 *         selector: "img",
 *     });
 *
 *   return {
 *      im,
 *      container: im.register(),
 *   }
 * }
 * // {{im.readyCount}}
 * // &lt;div v-bind:ref="container"&gt;&lt;/div&gt;
 * ```
 */

function useReadyElement(props) {
  if (props === void 0) {
    props = {};
  }

  return useImReady(__assign({
    usePreReadyElement: false,
    usePreReady: false
  }, props));
}

/**
 * Vue hook to check if the images or videos are loaded. (only usePreReady and useError are true)
 * @ko 이미지와 비디오들이 로드가 됐는지 체크하는 Vue hook.(usePreReady와 useError만 true)
 * @memberof Vue2ImReady
 * @param - Vue ImReady's props <ko>Vue ImReady의 props.</ko>
 * @example
 * ```js
 * import { usePreReady } from "@egjs/vue2-imready";
 *
 * setup() {
 *   const im = usePreReady({
 *         selector: "img",
 *     });
 *
 *   return {
 *      im,
 *      container: im.register(),
 *   }
 * }
 * // {{im.isPreReady}}
 * // &lt;div v-bind:ref="container"&gt;&lt;/div&gt;
 * ```
 */

function usePreReady(props) {
  if (props === void 0) {
    props = {};
  }

  return useImReady(__assign({
    usePreReadyElement: false,
    useReadyElement: false,
    useReady: false
  }, props));
}

/**
 * Vue hook to check if the images or videos are loaded. (only `useReady` and `useError` are true)
 * @ko 이미지와 비디오들이 로드가 됐는지 체크하는 vue hook.(`useReady`와 `useError`만 true)
 * @memberof Vue2ImReady
 * @param - Vue ImReady's props <ko>Vue ImReady의 props.</ko>
 * @example
 * ```js
 * import { useReady } from "@egjs/vue2-imready";
 *
 * setup() {
 *   const im = useReady({
 *         selector: "img",
 *     });
 *
 *   return {
 *      im,
 *      container: im.register(),
 *   }
 * }
 * // {{im.isReady}}
 * // &lt;div v-bind:ref="container"&gt;&lt;/div&gt;
 * ```
 */

function useReady(props) {
  if (props === void 0) {
    props = {};
  }

  return useImReady(__assign({
    usePreReadyElement: false,
    usePreReady: false,
    useReadyElement: false
  }, props));
}

exports.useImReady = useImReady;
exports.usePreReady = usePreReady;
exports.usePreReadyElement = usePreReadyElement;
exports.useReady = useReady;
exports.useReadyElement = useReadyElement;
//# sourceMappingURL=imready.cjs.js.map
