/*
Copyright (c) NAVER Corp.
name: @egjs/vue-infinitegrid
license: undefined
author: NAVER Corp.
repository: https://github.com/naver/egjs-infinitegrid/tree/main/packages/vue-infinitegrid
version: 4.1.0
*/
import VanillaInfiniteGrid, { FrameInfiniteGrid as FrameInfiniteGrid$1, JustifiedInfiniteGrid as JustifiedInfiniteGrid$1, MasonryInfiniteGrid as MasonryInfiniteGrid$1, PackingInfiniteGrid as PackingInfiniteGrid$1, Renderer, INFINITEGRID_EVENTS, mountRenderingItems, INFINITEGRID_METHODS, getRenderingItems, ITEM_TYPE } from '@egjs/infinitegrid';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/** @deprecated */

function __spreadArrays() {
  for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;

  for (var r = Array(s), k = 0, i = 0; i < il; i++) for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++) r[k] = a[j];

  return r;
}

var VUE_INFINITEGRID_PROPS = ["tag", "status", "useFirstRender", "itemBy", "groupBy"];

var FrameInfiniteGrid = makeInfiniteGrid("frame-infinite-grid", FrameInfiniteGrid$1);

var JustifiedInfiniteGrid = makeInfiniteGrid("justified-infinite-grid", JustifiedInfiniteGrid$1);

var MasonryInfiniteGrid = makeInfiniteGrid("masonry-grid", MasonryInfiniteGrid$1);

var PackingInfiniteGrid = makeInfiniteGrid("packing-infinite-grid", PackingInfiniteGrid$1);

function decamelize(str) {
  return str.replace(/([a-z])([A-Z])/g, function (_, letter, letter2) {
    return letter + "-" + letter2.toLowerCase();
  });
}

function makeInfiniteGrid(tagName, GridClass) {
  var propertyTypes = GridClass.propertyTypes,
      defaultOptions = GridClass.defaultOptions;
  var watch = {};

  var _loop_1 = function (name) {
    watch[name] = function (value) {
      this.$_grid[name] = value;
    };
  };

  for (var name in propertyTypes) {
    _loop_1(name);
  }

  var methods = {};
  INFINITEGRID_METHODS.forEach(function (name) {
    methods[name] = function () {
      var _a;

      var args = [];

      for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
      }

      return (_a = this.$_grid)[name].apply(_a, args);
    };
  });

  methods.$_getItemInfos = function () {
    var props = this.$props;
    var slots = this.$slots.default;

    var itemBy = props.itemBy || function (item, i) {
      var key = item.key;
      return key == null ? i : key;
    };

    var attributePrefix = props.attributePrefix || VanillaInfiniteGrid.defaultOptions.attributePrefix;

    var groupBy = props.groupBy || function (item) {
      var _a;

      var props = item.props || ((_a = item.data) === null || _a === void 0 ? void 0 : _a.attrs);
      return props ? props[attributePrefix + "groupkey"] : undefined;
    };

    var children = [];

    if (Array.isArray(slots)) {
      children = slots;
    } // Check Vue3 Slot Type


    return children.map(function (child, i) {
      return {
        groupKey: groupBy(child, i),
        key: itemBy(child, i),
        data: {
          vnode: child
        }
      };
    });
  };

  methods.$_getVisibleChildren = function () {
    var props = this.$props;
    var scopedSlots = this.$scopedSlots || this.$slots;
    var placeholder = scopedSlots.placeholder;
    var loading = scopedSlots.loading;
    var visibleItems = getRenderingItems(this.$_getItemInfos(), {
      grid: "$_grid" in this ? this.$_grid : null,
      status: props.status,
      horizontal: props.horizontal,
      useFirstRender: props.useFirstRender,
      usePlaceholder: !!scopedSlots.placeholder,
      useLoading: !!scopedSlots.loading
    });
    return visibleItems.map(function (item) {
      if (item.type === ITEM_TYPE.VIRTUAL) {
        return placeholder({
          item: item
        });
      } else if (item.type === ITEM_TYPE.LOADING) {
        return loading({
          item: item
        });
      } else {
        return item.data.vnode;
      }
    });
  };

  methods.$_renderContainer = function (h) {
    var props = this.$props;
    var visibleChildren = this.$_getVisibleChildren();
    var container = props.container; // eslint-disable-next-line @typescript-eslint/no-unused-vars

    var containerTag = props.containerTag || "div";

    if (container === true) {
      return [h(containerTag, {
        ref: "containerRef"
      }, visibleChildren)];
    }

    return visibleChildren;
  };

  return {
    name: tagName,
    props: __spreadArrays(VUE_INFINITEGRID_PROPS, Object.keys(defaultOptions)),
    watch: watch,
    methods: methods,
    render: function (h) {
      var props = this.$props;
      var tag = props.tag || "div";
      return h(tag, {
        ref: "wrapperRef"
      }, this.$_renderContainer(h));
    },
    created: function () {
      this.$_renderer = new Renderer();
    },
    mounted: function () {
      var _this = this;

      var defaultOptions = GridClass.defaultOptions;
      var options = {};
      var props = this.$props;
      var containerElement = this.$refs.containerRef;

      for (var name in defaultOptions) {
        if (name in props && typeof props[name] !== "undefined") {
          options[name] = props[name];
        }
      }

      if (containerElement) {
        options.container = containerElement;
      }

      options.renderer = this.$_renderer;
      var grid = new GridClass(this.$refs.wrapperRef, options);

      var _loop_2 = function (name) {
        var eventName = INFINITEGRID_EVENTS[name];
        var vueEventName = decamelize(eventName);
        grid.on(eventName, function (e) {
          _this.$emit(vueEventName, e);
        });
      };

      for (var name in INFINITEGRID_EVENTS) {
        _loop_2(name);
      }

      this.$_grid = grid;
      this.$_renderer.on("requestUpdate", function () {
        _this.$forceUpdate();
      });
      var scopedSlot = this.$scopedSlots || this.$slots;
      mountRenderingItems(this.$_getItemInfos(), {
        grid: this.$_grid,
        status: props.status,
        horizontal: props.horizontal,
        useFirstRender: props.useFirstRender,
        usePlaceholder: !!scopedSlot.placeholder,
        useLoading: !!scopedSlot.loading
      });
      this.$_renderer.updated();
    },
    updated: function () {
      this.$_renderer.updated();
    },
    beforeDestroy: function () {
      this.$_grid.destroy();
    }
  };
}
function install(app) {
  app.component("masonry-infinite-grid", MasonryInfiniteGrid);
  app.component("justified-infinite-grid", JustifiedInfiniteGrid);
  app.component("frame-infinite-grid", FrameInfiniteGrid);
  app.component("packing-infinite-grid", PackingInfiniteGrid);
}

export { FrameInfiniteGrid, JustifiedInfiniteGrid, MasonryInfiniteGrid, PackingInfiniteGrid, install, makeInfiniteGrid };
//# sourceMappingURL=infinitegrid.esm.js.map
